ArtifactsClient class final

Constructors

ArtifactsClient({required String baseUrl, required String machineCredential, ApiTransport? transport, Duration timeout = const Duration(seconds: 5)})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

artifact(String artifactId) Future<ApiResponse>
completeRevision(String artifactId, String revisionId, Map<String, Object?> completion, String idempotencyKey) Future<ApiResponse>
createArtifact(Map<String, Object?> artifact, String idempotencyKey) Future<ApiResponse>
createRevisionUploadIntent(String artifactId, Map<String, Object?> revision, String idempotencyKey) Future<ApiResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publishRevision(String artifactId, String revisionId, String idempotencyKey) Future<ApiResponse>
revision(String artifactId, String revisionId) Future<ApiResponse>
toString() String
A string representation of this object.
inherited
withdrawArtifact(String artifactId, String idempotencyKey) Future<ApiResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited