ApiException class final

Implemented types

Constructors

ApiException(int httpStatus, String code, String message, Map<String, Object?> details)
const

Properties

code String
final
details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
httpStatus int
final
isRetryable bool
no setter
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited