HttpApiTransport class final

Implemented types

Constructors

HttpApiTransport({Client? client})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send({required String method, required Uri uri, required Map<String, String> headers, String? body, required Duration timeout}) Future<TransportResponse>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited