AuthCallbackRequest class final

Constructors

AuthCallbackRequest({required String socketId, required Channel channel, required String channelName, required bool isPresence})
const

Properties

channel Channel
final
channelName String
final
hashCode int
The hash code for this object.
no setterinherited
isPresence bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited