DedupPolicy class final
Constructors
- DedupPolicy({required int maxEntries, required int maxAgeMs})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAgeMs → int
-
final
- maxEntries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited