DefaultRecoveryCoordinator class final

Implemented types

Constructors

DefaultRecoveryCoordinator({required List<RecoveryScopeBinding> scopes, required CursorStorePort cursorStore, required ClockPort clock, required SchedulerPort scheduler, TelemetrySinkPort telemetry = const _NoopTelemetrySink(), BackoffPolicy retryBackoff = _defaultRetryBackoff, int maxAttempts = _defaultMaxAttempts, RandomSource? random})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forgetCursors() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRecoveryNeeded(RecoveryContext context) → void
override
reset() → void
toString() RecoveryScope
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited