DefaultSubscriptionIntentRegistry class final

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAccountIntent(AccountChannel channel) SubscriptionIntent
override
addDeviceIntent(DeviceChannel channel) SubscriptionIntent
override
clear() List<SubscriptionIntent>
override
list() List<SubscriptionIntent>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIntent(String channelName) bool
override
setActiveRoomIntent(RoomChannel? channel) SubscriptionIntent?
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited