EphemeralPublishRequest class final

Constructors

EphemeralPublishRequest({required String channelName, required String socketId, required String auth, required String channelData, required Map<String, dynamic> envelope})
const

Properties

auth String
final
channelData String
final
channelName String
final
envelope Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited