LifecycleState enum

Inheritance
Available extensions

Values

idle → const LifecycleState
const LifecycleState('idle')
connecting → const LifecycleState
const LifecycleState('connecting')
connected → const LifecycleState
const LifecycleState('connected')
subscribing → const LifecycleState
const LifecycleState('subscribing')
disconnected → const LifecycleState
const LifecycleState('disconnected')
reconnectWait → const LifecycleState
const LifecycleState('reconnect-wait')
recovering → const LifecycleState
const LifecycleState('recovering')
stopped → const LifecycleState
const LifecycleState('stopped')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LifecycleState>
A constant List of the values in this enum, in order of their declaration.