RealtimeLifecycleClient class final

Constructors

RealtimeLifecycleClient({required LifecycleBootstrapConfig bootstrap, required SocketTransportPort transport, required ClockPort clock, required SchedulerPort scheduler, required AuthCallbackPort authCallback, required RecoveryCoordinatorPort recoveryCoordinator, LifecycleSignalSource signals = const _NoopSignalSource(), TelemetrySinkPort telemetry = const _NoopTelemetrySink(), EphemeralPublishPort? ephemeralPublisher, EnvelopeDecoderPort? envelopeDecoder, EventDispatcher? eventDispatcher, SubscriptionIntentRegistry? intentRegistry, DurableEventDeduplicator? dedup, DedupPolicy dedupPolicy = _defaultDedup, BackoffPolicy backoff = _defaultBackoff, RandomSource? random})

Properties

hashCode int
The hash code for this object.
no setterinherited
presenceSnapshot Map<String, PresenceMember>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAccountIntent(AccountChannel channel) SubscriptionIntent
addDeviceIntent(DeviceChannel channel) SubscriptionIntent
getState() LifecycleState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String domain, String type, EventHandler handler) → void Function()
onActiveRoomChanged(void handler(RoomChannel? room)) → void Function()
onPresenceEvent(void handler(PresenceEvent event)) → void Function()
onStateChange(void listener(LifecycleState from, LifecycleState to)) → void Function()
onUnknown(UnknownTypeHandler handler) → void Function()
removeIntent(String channelName) bool
requestRecovery() → void
resetForSessionChange() → void
restart() → void
sendTypingSignal({required String type, required String actor, required DateTime expiresAt, Map<String, dynamic> extraPayload = const {}, String? eventId}) Future<void>
setActiveRoom(RoomChannel? channel) → void
start() → void
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited