RecoveryContext class final

Constructors

RecoveryContext({required RecoveryReason reason, required int generation, required int occurredAt, required bool isCurrentGeneration()})
const

Properties

generation int
final
hashCode int
The hash code for this object.
no setterinherited
isCurrentGeneration bool Function()
final
occurredAt int
final
reason RecoveryReason
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited