RecoveryReason enum

Inheritance
Available extensions

Values

reconnectUncertain → const RecoveryReason
const RecoveryReason('reconnect-uncertain')
subscriptionLost → const RecoveryReason
const RecoveryReason('subscription-lost')
foregroundRestored → const RecoveryReason
const RecoveryReason('foreground-restored')
sessionChanged → const RecoveryReason
const RecoveryReason('session-changed')
manual → const RecoveryReason
const RecoveryReason('manual')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RecoveryReason>
A constant List of the values in this enum, in order of their declaration.