RecoveryScopeBinding class final

Constructors

RecoveryScopeBinding({required RecoveryScope scope, required RecoveryHandler handler})
const

Properties

handler RecoveryHandler
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope RecoveryScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() RecoveryScope
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited