StateTransitionTelemetryEvent class final

Inheritance

Constructors

StateTransitionTelemetryEvent({required LifecycleState from, required LifecycleState to, required int at})
const

Properties

at int
finalinherited
from LifecycleState
final
hashCode int
The hash code for this object.
no setterinherited
kind TelemetryEventKind
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to LifecycleState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited