- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAccountIntent(
AccountChannel channel) → SubscriptionIntent -
addDeviceIntent(
DeviceChannel channel) → SubscriptionIntent -
clear(
) → List< SubscriptionIntent> -
list(
) → List< SubscriptionIntent> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeIntent(
String channelName) → bool -
setActiveRoomIntent(
RoomChannel? channel) → SubscriptionIntent? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited