TypingIndicatorTracker class final
Constructors
-
TypingIndicatorTracker({required RealtimeLifecycleClient client, required ClockPort clock, required SchedulerPort scheduler, void onChange(Set<
String> typingActors)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
typingActors
→ Set<
String> -
no setter
Methods
-
clear(
) → void -
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited