menu
egensolve_realtime package
documentation
lifecycle.dart
DurableEventDeduplicator class
DurableEventDeduplicator class
dark_mode
light_mode
DurableEventDeduplicator
class
abstract
interface
Implementers
BoundedDurableEventDeduplicator
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
size
→
int
no setter
Methods
clear
(
)
→ void
hasSeen
(
String
id
,
int
now
)
→
bool
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prune
(
int
now
)
→ void
remember
(
String
id
,
int
now
)
→ void
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
egensolve_realtime package
documentation
lifecycle
DurableEventDeduplicator class
lifecycle library