RoomTypingSender class final
Constructors
- RoomTypingSender({required RealtimeLifecycleClient client, required ClockPort clock, required SchedulerPort scheduler, required String actor, Duration throttleInterval = const Duration(seconds: 3), Duration inactivityTimeout = const Duration(seconds: 5), Duration eventExpiry = const Duration(seconds: 8), String eventIdGenerator()?})
Properties
- eventExpiry → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactivityTimeout → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- throttleInterval → Duration
-
final
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyTyping(
) → void -
stopTyping(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited