TelemetryEventKind enum
Values
- stateTransition → const TelemetryEventKind
-
const TelemetryEventKind('state-transition') - reconnectAttempt → const TelemetryEventKind
-
const TelemetryEventKind('reconnect-attempt') - envelopeDropped → const TelemetryEventKind
-
const TelemetryEventKind('envelope-dropped') - eventDispatched → const TelemetryEventKind
-
const TelemetryEventKind('event-dispatched') - unknownTypeIgnored → const TelemetryEventKind
-
const TelemetryEventKind('unknown-type-ignored') - recoveryRequested → const TelemetryEventKind
-
const TelemetryEventKind('recovery-requested') - subscriptionIntentAdded → const TelemetryEventKind
-
const TelemetryEventKind('subscription-intent-added') - subscriptionIntentRemoved → const TelemetryEventKind
-
const TelemetryEventKind('subscription-intent-removed') - subscriptionEstablished → const TelemetryEventKind
-
const TelemetryEventKind('subscription-established') - subscriptionFailed → const TelemetryEventKind
-
const TelemetryEventKind('subscription-failed') - recoveryApplied → const TelemetryEventKind
-
const TelemetryEventKind('recovery-applied') - recoveryApplyFailed → const TelemetryEventKind
-
const TelemetryEventKind('recovery-apply-failed') - recoverySuperseded → const TelemetryEventKind
-
const TelemetryEventKind('recovery-superseded') - cursorCorrupted → const TelemetryEventKind
-
const TelemetryEventKind('cursor-corrupted') - sessionReset → const TelemetryEventKind
-
const TelemetryEventKind('session-reset')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TelemetryEventKind> - A constant List of the values in this enum, in order of their declaration.