HttpEphemeralPublishCallback class final
- Implemented types
Constructors
- HttpEphemeralPublishCallback({required String endpoint, Client? client, EphemeralPublishHeaderProvider? headerProvider})
Properties
- endpoint → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerProvider → EphemeralPublishHeaderProvider?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
EphemeralPublishRequest request) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited