Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asset(String assetId)
→ Future<ApiResponse>
-
-
completeUpload(String assetId, Map<String, Object?> completion, String idempotencyKey)
→ Future<ApiResponse>
-
-
createDownloadGrant(String assetId, Map<String, Object?> grant, String idempotencyKey)
→ Future<ApiResponse>
-
-
createMultipartPartIntent(String assetId, int partNumber, Map<String, Object?> part, String idempotencyKey)
→ Future<ApiResponse>
-
-
createUploadIntent(Map<String, Object?> intent, String idempotencyKey)
→ Future<ApiResponse>
-
-
deleteAsset(String assetId, String idempotencyKey)
→ Future<ApiResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited